NLSL: ftwork.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

ftwork.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module FTWORK
5 c =========================
6 c
7 c Defines and saves working arrays used for correlation and
8 c convolution function calculations by Fourier transform methods
9 c
10 c tmpclc Temporary storage array for calculated spectrum
11 c used by function sshift (calls subroutine correl)
12 c and by subroutine eprls (and subroutine convlv)
13 c
14 c tmpdat Temporary storage array for data
15 c used by function sshift (calls subroutine correl)
16 c and by subroutine eprls (and subroutine convlv)
17 c
18 c work,work2 Temporary work array used by correl (and convlv)
19 c
20 c----------------------------------------------------------------------
21 c
22 module ftwork
23 use nlsdim
24 implicit none
25 c
26 double precision, dimension (MXPT), save ::
27 # work, work2, tmpclc, tmpdat
28 c
29 end module ftwork
30
ftwork::work2
double precision, dimension(mxpt), save work2
Definition: ftwork.f90:26
ftwork::tmpdat
double precision, dimension(mxpt), save tmpdat
Definition: ftwork.f90:26
ftwork
Definition: ftwork.f90:22
nlsdim
Definition: nlsdim.f90:36
ftwork::tmpclc
double precision, dimension(mxpt), save tmpclc
Definition: ftwork.f90:26
ftwork::work
double precision, dimension(mxpt), save work
Definition: ftwork.f90:26